| country_codes | R Documentation |
A dataset containing country codes used in the Catálogo Taxonômico da Fauna
do Brasil along with their corresponding country names, as defined in
faunabr::world_fauna.
data(country_codes)
A data.frame with 244 rows and 2 variables:
Country names as defined in faunabr::world_fauna.
Country codes used in the Catálogo Taxonômico da Fauna do Brasil.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.