View source: R/fauna_attributes.R
| fauna_attributes | R Documentation |
This function displays all the options available to filter species by its characteristics
fauna_attributes(data, attribute)
data |
(data.frame) a data.frame imported with the
|
attribute |
(character) the type of characteristic. Accept more than one option. See detail to see the options. |
The attribute argument accepts the following options: phylum, class, family, genus, lifeForm, habitat, states, country, origin, and taxonomicstatus. These options represent different characteristics of species that can be used for filtering.
a list of data.frames with the available options to use in the
select_fauna function.
data("fauna_data") #Load data example
# Get available states, countries and lifeForms to filter species
d <- fauna_attributes(data = fauna_data,
attribute = c("country", "lifeform", "states"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.