View source: R/fauna_by_vernacular.R
| fauna_by_vernacular | R Documentation |
Search for taxa using vernacular names
fauna_by_vernacular(data, names, exact = FALSE)
data |
(data.frame) the data.frame imported with the
|
names |
(character) vernacular name ("Nome comum") of the species to be searched |
exact |
(logic) if TRUE, the function will search only for exact matches. For example, if names = "veado-mateiro" and exact = TRUE, the function will return only the species popularly known as "veado-mateiro". On the other hand, if names = "veado-mateiro" and exact = FALSE, the function will return other results as "Veado-mateiro-pequeno". Default = FALSE |
a data.frame with the species with vernacular names that match the input names
data("fauna_data") #Load Fauna do Brasil data
#Search for species whose vernacular name is 'veado-mateiro'
veado_exact <- fauna_by_vernacular(data = fauna_data,
names = "veado-mateiro",
exact = TRUE)
veado_exact
#Search for species whose vernacular name is 'veado_mateiro', allowing non-exact
#matches
veado_not_exact <- fauna_by_vernacular(data = fauna_data,
names = "veado-mateiro",
exact = FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.