fauna_discrepancies: Resolve discrepancies between species and subspecies...

View source: R/fauna_discrepancies.R

fauna_discrepanciesR Documentation

Resolve discrepancies between species and subspecies information

Description

Resolve discrepancies between species and subspecies information

Usage

fauna_discrepancies(data)

Arguments

data

(data.frame) the data.frame imported with the load_faunabr function.

Details

In the original dataset, discrepancies may exist between species and subspecies information. An example of a discrepancy is when species occurs only in one state (e.g., SP), but a subspecies or variety of the same species occurs in another states (e.g., SP and RJ). This function rectifies such discrepancies by considering distribution (states and countries) life form, and habitat. For instance, if a subspecies is recorded in a specific state, it implies that the species also occurs in that state

Value

a data.frame with the discrepancies solved

Examples

data("fauna_data") #Load fauna e Funga do Brasil data
#Check if discrepancies were solved in the dataset
attr(fauna_data, "solved_discrepancies")
#Solve discrepancies
fauna_solved <- fauna_discrepancies(fauna_data)
#Check if discrepancies were solved in the dataset
attr(fauna_solved, "solved_discrepancies")

faunabr documentation built on Nov. 5, 2025, 7:26 p.m.