fauna_version: Check if you have the latest version of Fauna do Brasil data...

View source: R/fauna_version.R

fauna_versionR Documentation

Check if you have the latest version of Fauna do Brasil data available

Description

This function checks if you have the latest version of the Fauna do Brasil data available in a specified directory.

Usage

fauna_version(data_dir)

Arguments

data_dir

the directory where the data should be located.

Value

A message informing whether you have the latest version of Fauna do Brasil available in the data_dir

Examples

#Check if there is a version of Fauna do Brasil data available in the
#current directory
fauna_version(data_dir = getwd())

faunabr documentation built on Nov. 5, 2025, 7:26 p.m.