| subset_fauna | R Documentation |
Returns a data.frame with a subset of species from Fauna do Brasil database
subset_fauna(data, species, include_subspecies = FALSE)
data |
(data.frame) the data.frame imported with the
|
species |
(character) names of the species to be extracted from Fauna do Brasil database. |
include_subspecies |
(logical) include subspecies? Default = FALSE |
A data.frame with the selected species.
data("fauna_data") #Load data example
#Species to extract from database
spp <- c("Panthera onca", "Mazama jucunda", "Subulo gouzoubira")
spp_subset <- subset_fauna(data = fauna_data, species = spp,
include_subspecies = FALSE)
spp_subset
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.