A dataset containing country codes used in the Catálogo Taxonômico da Fauna
do Brasil along with their corresponding country names, as defined in
faunabr::world_fauna.
Usage
data(country_codes)
Arguments
Format
A data.frame with 244 rows and 2 variables:
map_name
Country names as defined in faunabr::world_fauna.
country_code
Country codes used in the Catálogo Taxonômico da Fauna
do Brasil.