Learn R Programming

faunabr (version 1.0.0)

fauna_attributes: Get available attributes to filter species

Description

This function displays all the options available to filter species by its characteristics

Usage

fauna_attributes(data, attribute)

Value

a list of data.frames with the available options to use in the select_fauna function.

Arguments

data

(data.frame) a data.frame imported with the load_faunabr function or a data.frame generated with the select_fauna function.

attribute

(character) the type of characteristic. Accept more than one option. See detail to see the options.

Details

The attribute argument accepts the following options: phylum, class, family, genus, lifeForm, habitat, states, country, origin, and taxonomicstatus. These options represent different characteristics of species that can be used for filtering.

Examples

Run this code
data("fauna_data") #Load data example
# Get available states, countries and lifeForms to filter species
d <- fauna_attributes(data = fauna_data,
                    attribute = c("country", "lifeform", "states"))

Run the code above in your browser using DataLab