View source: R/fauna_version.R
| fauna_version | R Documentation |
This function checks if you have the latest version of the Fauna do Brasil data available in a specified directory.
fauna_version(data_dir)
data_dir |
the directory where the data should be located. |
A message informing whether you have the latest version of Fauna do Brasil available in the data_dir
#Check if there is a version of Fauna do Brasil data available in the
#current directory
fauna_version(data_dir = getwd())
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.