Learn R Programming

faunabr (version 1.0.0)

fauna_version: Check if you have the latest version of Fauna do Brasil data available

Description

This function checks if you have the latest version of the Fauna do Brasil data available in a specified directory.

Usage

fauna_version(data_dir)

Value

A message informing whether you have the latest version of Fauna do Brasil available in the data_dir

Arguments

data_dir

the directory where the data should be located.

Examples

Run this code
#Check if there is a version of Fauna do Brasil data available in the
#current directory
fauna_version(data_dir = getwd())

Run the code above in your browser using DataLab