powered by
This function checks if you have the latest version of the Fauna do Brasil data available in a specified directory.
fauna_version(data_dir)
A message informing whether you have the latest version of Fauna do Brasil available in the data_dir
the directory where the data should be located.
#Check if there is a version of Fauna do Brasil data available in the #current directory fauna_version(data_dir = getwd())
Run the code above in your browser using DataLab