- data
(data.frame) the data.frame imported with the
load_faunabr function.
- occ
(data.frame) a data.frame with the records of the species.
- species
(character) column name in occ with species names.
Default = "species"
- long
(character) column name in occ with longitude data. Default = "x"
- lat
(character) column name in occ with latitude data. Default = "y"
- by_state
(logical) filter records by state? Default = TRUE
- buffer_state
(numeric) buffer (in km) around the polygons of the
states of occurrence of the specie. Default = 20.
- by_country
(logical) filter records by country? Default = TRUE
- buffer_country
(numeric) buffer (in km) around the polygons of the
countries of occurrence of the specie. Default = 20.
- value
(character) Defines output values. See Value section.
Default = "flag&clean".
- keep_columns
(logical) if TRUE, keep all the original columns of the
input occ. If False, keep only the columns species, long and lat.
Default = TRUE
- spat_state
(SpatVector) a SpatVector of the Brazilian states. By
default, it uses the SpatVector provided by geobr::read_state(). It can be
another Spatvector, but the structure must be identical to
'faunabr::states', with a column called "abbrev_state" identifying the states
codes.
- spat_country
(SpatVector) a SpatVector of the world countries. By
default, it uses the SpatVector provided by rnaturalearth::ne_countries. It
can be another Spatvector, but the structure must be identical to
'faunabr::world_fauna', with a column called "country_code" identifying the
country codes.
- verbose
(logical) Whether to display species being filtered during
function execution. Set to TRUE to enable display, or FALSE to run silently.
Default = TRUE.