- output_dir
(character) a directory to save the data downloaded from
Fauna do Brasil
- data_version
(character) Version of the Fauna do Brasil database to
download. Use "latest" to get the most recent version, which is updated
frequently. Alternatively, specify an older version (e.g.,
data_version = "1.2").Default value is "latest".
- solve_discrepancies
Resolve inconsistencies between species and
subspecies information. When set to TRUE (default), species
information is updated based on unique data from subspecies.
For example, if a subspecies occurs in a certain state, it implies that the
species also occurs in that state.
- translate
(logical) whether to translate the original dataset
("lifeForm", "origin", "habitat", and "taxonRank") from Portuguese to English.
Default is TRUE.
- overwrite
(logical) If TRUE, data is overwritten. Default = TRUE.
- verbose
(logical) Whether to display messages during function
execution. Set to TRUE to enable display, or FALSE to run silently.
Default = TRUE.